@@ -14,9 +14,16 @@ export type SaveGlobalOptionsActionType = {
   payload: {|
     refreshInterval?: number,
     language?: string,
+    persistLocale?: boolean,
     showNotifications?: boolean,
     notificationSnoozeDuration?: number,
-    sshKey?: string
+    sshKey?: string,
+    preferredConsole?: string,
+    fullScreenVnc?: boolean,
+    ctrlAltEndVnc?: boolean,
+    fullScreenSpice?: boolean,
+    ctrlAltEndSpice?: boolean,
+    smartcardSpice?: boolean
   |},
   meta: {|
     transactionId: string
