@@ -4,7 +4,7 @@ import { resourcesUrls } from '_/branding'
 
 const Header = ({ children }) => {
   return (
-    <nav className='navbar obrand_mastheadBackground obrand_topBorder navbar-pf-vertical'>
+    <nav className='navbar navbar-pf-vertical obrand_masthead' role='navigation'>
       <div className='navbar-header'>
         <a href='/' className='navbar-brand obrand_headerLogoLink' id='pageheader-logo'>
           <img className='obrand_mastheadLogo' src={resourcesUrls.clearGif} />
