@@ -7,7 +7,7 @@ import { SET_TEMPLATES } from '_/constants'
 const initialState = fromJS({})
 
 const templates = actionReducer(initialState, {
-  [SET_TEMPLATES] (state, { payload: templates }) {
+  [SET_TEMPLATES] (state, { payload: { templates } }) {
     const idToTemplate = arrayToMap(templates, template => template.id)
     return fromJS(idToTemplate)
   },
